==> nextcloud-32.0.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/activity/l10n/es_MX.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Fuente de actividad personal para %s",
    "Your feed URL is invalid" : "La URL de tu fuente de es inválida",
    "Activity feed for %1$s" : "Fuente de actividad para %1$s",
    "Activity feed" : "Fuente de actividad",
    "Your settings have been updated." : "Tus configuraciones se han actualizado.",
    "Settings have been updated." : "Las configuraciones han sido actualizadas",
    "Recent activity" : "Actividad reciente",
    "No activities" : "No hay actividades",
    "More activities" : "Más actividades",
    "Daily activity summary for %s" : "Resumen de la actividad reciente para %s",
    "_and %n more…_::_and %n more…_" : ["y %n más...","y %n más...","y %n más..."],
    "All activities" : "Todas las actividades",
    "By others" : "Por otros",
    "By you" : "Por usted",
    "Activity at %s" : "Actividad al %s",
    "Hello %s" : "Hola %s",
    "Hello %s," : "Hola %s,",
    "There was some activity at %s" : "Se tuvo algo de actividad en %s",
    "_and %n more _::_and %n more _" : ["y %n más","y %n más","y %n más"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Puede cambiar la frecuencia de estos correos electrónicos o desactivarlos en la <a href=\"%s\">configuración</a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "Puede cambiar la frecuencia de estos correos electrónicos o desactivarlos en la configuración: %s",
    "Mail" : "Correo",
    "Push" : "Instantánea",
    "Activity" : "Actividad",
    "Notifications" : "Notificaciones",
    "This application enables people to view a log of activities about them, their files or other data." : "Esta aplicación permite ver un registro de actividades de los usuarios, sus archivos u otros datos.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Esta aplicación posibilita a los usuario ver acciones relacionadas con sus archivos y datos en Nextcloud.\n\t\tCada persona puede configurar sus ajustes de actividad en las opciones personales,\n\t\tpara seleccionar que actividad debería ser transferida a su teléfono móvil, enviada por correo\n\t\to si un resumen diario se envía cada mañana.\n\t\tExiste más información disponible en la documentación de actividad.",
    "Send email" : "Enviar correo electrónico",
    "Send push notification" : "Enviar notificación push",
    "Activity notification configuration" : "Configuración de las notificaciones de actividad",
    "Today" : "Hoy",
    "Yesterday" : "Ayer",
    "You need to set up your email address before you can receive notification emails." : "Necesitas configurar tu dirección de correo electrónico antes de que puedas recibir correos de notificación",
    "Send activity emails" : "Enviar correos de actividad",
    "As soon as possible" : "Lo antes posible",
    "Hourly" : "Cada hora",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "You commented" : "Comentaste",
    "Message deleted by author" : "Mensaje eliminado por el autor",
    "Open {filename}" : "Abrir {filename}",
    "in {path}" : "en {path}",
    "Home" : "Inicio",
    "Could not load activities" : "No se pudieron cargar las actividades",
    "Loading activities" : "Cargando actividades",
    "This stream will show events like additions, changes & shares" : "Este flujo mostrará eventos tales como añadir, cambiar & compartir",
    "No activity yet" : "Aún no tiene actividad",
    "Loading more activities" : "Cargando más actividades",
    "No more activities." : "No hay más actividades.",
    "Could not enable RSS link" : "No se pudo habilitar el enlace RSS",
    "RSS link copied to clipboard" : "Enlace RSS copiado al portapapeles",
    "Could not copy the RSS link, please copy manually:" : "No se pudo copiar el enlace RSS, por favor, cópielo manualmente:",
    "Activity settings" : "Configuraciones de actividad",
    "Enable RSS feed" : "Habilitar fuente RSS",
    "RSS feed" : "Fuente RSS",
    "Copy RSS feed link" : "Copiar el enlace de la fuente RSS",
    "Personal notification settings" : "Configuración de notificaciones personales",
    "Unable to load the activity list" : "No se puede cargar la lista de actividad.",
    "Choose for which activities you want to get an email or push notification." : "Elige las actividades para las que prefieres recibir un correo electrónico o una notificación en tu dispositivo móvil.",
    "Choose for which activities you want to get a push notification." : "Elige las actividades para las que deseas obtener notificación en tu dispositivo móvil.",
    "Notification" : "Notificación",
    "Enable notification emails" : "Habilitar correos de notificación.",
    "Daily activity summary" : "Resumen diario de actividad",
    "Send daily activity summary in the morning" : "Enviar un resumen de actividad, todos los días por la mañana.",
    "Default settings" : "Configuraciones predeterminadas",
    "Configure the default notification settings for new accounts." : "Establezca las configuraciones de notificación por defecto para cuentas nuevas.",
    "Unable to save the settings" : "No fue posible guardar las configuraciones.",
    "No more events to load" : "No hay más eventos por cargar"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-32.0.6-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/activity/l10n/es_MX.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Fuente de actividad personal para %s",
    "Your feed URL is invalid" : "La URL de tu fuente de es inválida",
    "Activity feed for %1$s" : "Canal de actividad para%1$s",
    "Activity feed" : "Fuente de actividad",
    "Your settings have been updated." : "Tus configuraciones se han actualizado.",
    "Settings have been updated." : "Las configuraciones han sido actualizadas",
    "remote user" : "Usuario remoto",
    "Recent activity" : "Actividad reciente",
    "No activities" : "No hay actividades",
    "More activities" : "Más actividades",
    "Daily activity summary for %s" : "Resumen de la actividad reciente para %s",
    "_and %n more…_::_and %n more…_" : ["y %n más...","y %n más...","y %n más..."],
    "You can disable daily digest emails in the <a href=\"%s\">settings</a>." : "Puedes desactivar los correos del resumen diario en la <a href=\"%s\">configuración</a>",
    "You can disable daily digest emails in the settings: %s" : "Puedes desactivar los correos del resumen diario en la configuración:%s",
    "All activities" : "Todas las actividades",
    "By others" : "Por otros",
    "By you" : "Por usted",
    "Activity at %s" : "Actividad al %s",
    "Hello %s" : "Hola %s",
    "Hello %s," : "Hola %s,",
    "There was some activity at %s" : "Se tuvo algo de actividad en %s",
    "_and %n more _::_and %n more _" : ["y %n más","y %n más","y %n más"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Puede cambiar la frecuencia de estos correos electrónicos o desactivarlos en la <a href=\"%s\">configuración</a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "Puede cambiar la frecuencia de estos correos electrónicos o desactivarlos en la configuración: %s",
    "Mail" : "Correo",
    "Push" : "Instantánea",
    "Activity" : "Actividad",
    "Notifications" : "Notificaciones",
    "This application enables people to view a log of activities about them, their files or other data." : "Esta aplicación permite ver un registro de actividades de los usuarios, sus archivos u otros datos.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Esta aplicación posibilita a los usuario ver acciones relacionadas con sus archivos y datos en Nextcloud.\n\t\tCada persona puede configurar sus ajustes de actividad en las opciones personales,\n\t\tpara seleccionar que actividad debería ser transferida a su teléfono móvil, enviada por correo\n\t\to si un resumen diario se envía cada mañana.\n\t\tExiste más información disponible en la documentación de actividad.",
    "Send email" : "Enviar correo electrónico",
    "Send push notification" : "Enviar notificación push",
    "Activity notification configuration" : "Configuración de las notificaciones de actividad",
    "Today" : "Hoy",
    "Yesterday" : "Ayer",
    "You need to set up your email address before you can receive notification emails." : "Necesitas configurar tu dirección de correo electrónico antes de que puedas recibir correos de notificación",
    "Send activity emails" : "Enviar correos de actividad",
    "As soon as possible" : "Lo antes posible",
    "Hourly" : "Cada hora",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "You commented" : "Comentaste",
    "Message deleted by author" : "Mensaje eliminado por el autor",
    "Open {filename}" : "Abrir {filename}",
    "in {path}" : "en {path}",
    "Home" : "Inicio",
    "Could not load activities" : "No se pudieron cargar las actividades",
    "Loading activities" : "Cargando actividades",
    "This stream will show events like additions, changes & shares" : "Este flujo mostrará eventos tales como añadir, cambiar & compartir",
    "No activity yet" : "Aún no tiene actividad",
    "Loading more activities" : "Cargando más actividades",
    "No more activities." : "No hay más actividades.",
    "Could not enable RSS link" : "No se pudo habilitar el enlace RSS",
    "RSS link copied to clipboard" : "Enlace RSS copiado al portapapeles",
    "Could not copy the RSS link, please copy manually:" : "No se pudo copiar el enlace RSS, por favor, cópielo manualmente:",
    "Activity settings" : "Configuraciones de actividad",
    "Enable RSS feed" : "Habilitar fuente RSS",
    "RSS feed" : "Fuente RSS",
    "Copy RSS feed link" : "Copiar el enlace de la fuente RSS",
    "Personal notification settings" : "Configuración de notificaciones personales",
    "Unable to load the activity list" : "No se puede cargar la lista de actividad.",
    "Choose for which activities you want to get an email or push notification." : "Elige las actividades para las que prefieres recibir un correo electrónico o una notificación en tu dispositivo móvil.",
    "Choose for which activities you want to get a push notification." : "Elige las actividades para las que deseas obtener notificación en tu dispositivo móvil.",
    "Notification" : "Notificación",
    "Enable notification emails" : "Habilitar correos de notificación.",
    "Daily activity summary" : "Resumen diario de actividad",
    "Send daily activity summary in the morning" : "Enviar un resumen de actividad, todos los días por la mañana.",
    "Default settings" : "Configuraciones predeterminadas",
    "Configure the default notification settings for new accounts." : "Establezca las configuraciones de notificación por defecto para cuentas nuevas.",
    "Unable to save the settings" : "No fue posible guardar las configuraciones.",
    "No more events to load" : "No hay más eventos por cargar"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
